@@ -10,7 +10,7 @@
  *  based on the GKK algorithm by Gustavson, Karlsson, Kagstrom
  *  and its fortran implementation.
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Mathieu Faverge
  * @date 2010-11-15
  *
@@ -22,8 +22,6 @@
 #include <sys/types.h>
 #include <assert.h>
 #include "common.h"
-#include "primes.h"
-#include "gkkleader.h"
 
 /** ****************************************************************************
  *
@@ -131,7 +129,7 @@ int plasma_zshift(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A,
             for (ip=0; ip<nprob_per_grp; ip++) {
                 for (i=0; i<nleaders; i++) {
                     /* assign this cycle to a thread */
-                    owner = minloc(thrdbypb, Tp);
+                    owner = GKK_minloc(thrdbypb, Tp);
 
                     /* assign it to owner */
                     Tp[owner] = Tp[owner] + tmp[1] * L;
