@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @date 2010-11-15
  * @precisions normal z -> s d c
@@ -501,7 +501,7 @@ int PLASMA_zgesvd_Tile_Async(PLASMA_enum jobu, PLASMA_enum jobvt,
             plasma_error("PLASMA_zgesvd","ZGESVD");
         }
         sequence->status = status;
-        plasma_setlapack_sequential();
+        plasma_setlapack_sequential(plasma);
         #if defined(ENABLE_TIMER)
         timelpk = PLASMA_Wtime()-timelpk;
         printf("  Finish Eigensolver-lpkonly timing= %lf  threads %d\n" ,timelpk, plasma->world_size);
@@ -974,7 +974,7 @@ int PLASMA_zgesvd_Tile_Async(PLASMA_enum jobu, PLASMA_enum jobvt,
         /*return status;*/
     }
     sequence->status = status;
-    plasma_setlapack_sequential();
+    plasma_setlapack_sequential(plasma);
     #if defined(ENABLE_TIMER)
     timelpk = PLASMA_Wtime()-timelpk;
     printf("  Finish Eigensolver timing= %lf  WANTZ %d threads %d\n" ,timelpk, WANTZ,  plasma->world_size);
