@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @author Hatem Ltaief
  * @date 2010-11-15
@@ -677,7 +677,7 @@ int PLASMA_zheev_Tile_Async(PLASMA_enum jobz, PLASMA_enum uplo,
         /*return status;*/
     }
     sequence->status = status;
-    plasma_setlapack_sequential();
+    plasma_setlapack_sequential(plasma);
     /*=======================================
      *  END of calling eigensolver
      *=======================================*/
