@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @author Hatem Ltaief
  * @date 2010-11-15
@@ -548,10 +548,6 @@ int PLASMA_zheevd_Tile_Async(PLASMA_enum jobz, PLASMA_enum uplo,
     /*=======================================
      *  calling eigensolver
      *=======================================*/
-#if defined(PLASMA_WITH_ACML)
-    plasma_unsetaffinity();
-    omp_set_num_threads( plasma->world_size );
-#endif
     /* call eigensolver using lapack routine for our resulting tridiag [D E] */
     plasma_setlapack_multithreads(plasma->world_size);
     /*
@@ -564,17 +560,13 @@ int PLASMA_zheevd_Tile_Async(PLASMA_enum jobz, PLASMA_enum uplo,
         status = LAPACKE_zstedc( LAPACK_COL_MAJOR, lapack_const(PlasmaIvec),
                         N, W, E, Q, LDQ );
     }
-#if defined(PLASMA_WITH_ACML)
-    omp_set_num_threads( 1 );
-    plasma_setaffinity(0);
-#endif
 
     if(status != 0){
         plasma_error("PLASMA_zstedc","ZSTEDC");
         return status;
     }
     sequence->status = status;
-    plasma_setlapack_sequential();
+    plasma_setlapack_sequential(plasma);
     /*=======================================
      *  END of calling eigensolver
      *=======================================*/
