@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @author Hatem Ltaief
  * @date 2010-11-15
@@ -672,7 +672,7 @@ int PLASMA_zheevr_Tile_Async(PLASMA_enum jobz, PLASMA_enum range, PLASMA_enum up
         return PLASMA_ERR_UNEXPECTED;
     }
     sequence->status = status;
-    plasma_setlapack_sequential();
+    plasma_setlapack_sequential(plasma);
     /*=======================================
      *  END of calling eigensolver
      *=======================================*/
