@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Jakub Kurzak
  * @author Ichitaro Yamazaki
  * @author Mathieu Faverge
@@ -20,17 +20,6 @@
 #undef REAL
 #define COMPLEX
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-
-/* Temporary declaration of zlacn2, should be remove with future version of Lapacke */
-int LAPACK_GLOBAL(zlacn2, ZLACN2)( int *N, PLASMA_Complex64_t *V, PLASMA_Complex64_t *X,
-#if !defined(COMPLEX)
-                                   int *ISGN,
-#endif
-                                   double *EST, int *KASE, int *ISAVE);
-
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
-
 /***************************************************************************//**
  *
  * @ingroup PLASMA_Complex64_t
@@ -324,9 +313,9 @@ int PLASMA_zpocon_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, double Anorm, dou
     do {
         itrs ++;
 #if defined(REAL)
-        LAPACK_GLOBAL(zlacn2, ZLACN2)(&(descA.m), workN, descW.mat, isgn, &Ainvnorm, &kase, isave);
+        LAPACKE_zlacn2_work( descA.m, workN, descW.mat, isgn, &Ainvnorm, &kase, isave);
 #else
-        LAPACK_GLOBAL(zlacn2, ZLACN2)(&(descA.m), workN, descW.mat,       &Ainvnorm, &kase, isave);
+        LAPACKE_zlacn2_work( descA.m, workN, descW.mat,       &Ainvnorm, &kase, isave);
 #endif
 
 #define FALLBACK
