@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Jakub Kurzak
  * @author Mathieu Faverge
  * @date 2010-11-15
@@ -100,7 +100,7 @@ void plasma_pzlansy (plasma_context_t *plasma);
 void plasma_pzpack  (plasma_context_t *plasma);
 void plasma_pzplghe (plasma_context_t *plasma);
 void plasma_pzplgsy (plasma_context_t *plasma);
-void plasma_pzplrnt (plasma_context_t *plasma);
+void plasma_pzpltmg(plasma_context_t *plasma);
 void plasma_pzpotrf (plasma_context_t *plasma);
 void plasma_pzshift (plasma_context_t *plasma);
 void plasma_pzsymm  (plasma_context_t *plasma);
@@ -127,6 +127,8 @@ void plasma_pzlarft_blgtrd(plasma_context_t *plasma);
 int plasma_zshift(plasma_context_t *plasma, int m, int n, PLASMA_Complex64_t *A,
                   int nprob, int me, int ne, int L,
                   PLASMA_sequence *sequence, PLASMA_request *request);
+void plasma_zpltmg_condex(PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_zpltmg_house( PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
 
 /***************************************************************************//**
  *  Declarations of parallel functions (dynamic scheduling) - alphabetical order
@@ -178,6 +180,7 @@ void plasma_pzlange_quark(PLASMA_enum norm, PLASMA_desc A, double *work, double
 void plasma_pzlanhe_quark(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc A, double *work, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
 #endif
 void plasma_pzlansy_quark(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc A, double *work, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
+void plasma_pzlantr_quark(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, PLASMA_desc A, double *work, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzlaset_quark( PLASMA_enum uplo, PLASMA_Complex64_t alpha, PLASMA_Complex64_t beta, PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzlaset2_quark(PLASMA_enum uplo, PLASMA_Complex64_t alpha,                          PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzlaswp_quark(PLASMA_desc B, const int *IPIV, int inc, PLASMA_sequence *sequence, PLASMA_request *request);
@@ -185,7 +188,12 @@ void plasma_pzlaswpc_quark(PLASMA_desc B, const int *IPIV, int inc, PLASMA_seque
 void plasma_pzlauum_quark(PLASMA_enum uplo, PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzplghe_quark(double bump, PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzplgsy_quark(PLASMA_Complex64_t bump, PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
-void plasma_pzplrnt_quark(PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_quark(PLASMA_enum mtxtype, PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_fiedler_quark(PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_toeppd_quark( PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_circul_quark( PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_chebvand_quark( PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request );
+void plasma_pzpltmg_hankel_quark( PLASMA_desc A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request );
 void plasma_pzpotrf_quark(PLASMA_enum uplo, PLASMA_desc A, PLASMA_sequence *sequence, PLASMA_request *request);
 void plasma_pzshift_quark(int, int, int, PLASMA_Complex64_t *, int *, int, int, int, PLASMA_sequence*, PLASMA_request*);
 void plasma_pzsymm_quark(PLASMA_enum side, PLASMA_enum uplo, PLASMA_Complex64_t alpha, PLASMA_desc A, PLASMA_desc B, PLASMA_Complex64_t beta, PLASMA_desc C, PLASMA_sequence *sequence, PLASMA_request *request);
