@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @date 2010-11-15
  *
@@ -54,9 +54,20 @@ void plasma_setlapack_multithreads(int num_threads)
 /***************************************************************************//**
  * switch lapack to sequential and setting plasma affinity
  **/
-void plasma_setlapack_sequential()
+void plasma_setlapack_sequential(plasma_context_t *plasma)
 {
-    plasma_context_t *plasma = plasma_context_self();
-    plasma_setlapack_numthreads(1);
+    /*
+     * All threads need to call the parallel section that 
+     * set omp/mkl numthreads to 1, then only the master (0) will 
+     * set plasma affinity 
+     */
+    plasma_static_call(plasma_psetlapack_numthreads);
     plasma_setaffinity(plasma->thread_bind[0]);
 }
+
+void plasma_psetlapack_numthreads(plasma_context_t *plasma)
+{
+    plasma_setlapack_numthreads(1);
+}
+
+
