@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Azzam Haidar
  * @date 2010-11-15
  *
@@ -21,7 +21,8 @@ extern "C" {
  *  Internal routines
  **/
 void plasma_setlapack_multithreads(int numthreads);
-void plasma_setlapack_sequential();
+void plasma_setlapack_sequential(plasma_context_t *plasma);
+void plasma_psetlapack_numthreads(plasma_context_t *plasma);
 /***************************************************************************/
 #ifdef __cplusplus
 }
