@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Mark Gates
  * @date 2010-11-15
  * @precisions normal z -> c d s
@@ -82,10 +82,10 @@ void CORE_zgeqp3_larfg( PLASMA_desc A, int ii, int jj, int i, int j,
     double norm2;
     PLASMA_Complex64_t x0, scale;
     PLASMA_Complex64_t *Akj, *Aij;
-    
+
     /* TODO: it might be simpler to pass in global (i,j) indices, */
     /* from which (ii,jj) can be derived. */
-    
+
     /* compute norm( A[i+1:m,j] )^2 */
     /* todo: use lassq algorithm */
     i2 = i+1;
@@ -99,7 +99,7 @@ void CORE_zgeqp3_larfg( PLASMA_desc A, int ii, int jj, int i, int j,
         }
         i2 = 0;
     }
-    
+
     lda = BLKLDD( A, ii );
     Aij = A(ii,jj);
     x0 = Aij[i + j*lda];
@@ -118,7 +118,7 @@ void CORE_zgeqp3_larfg( PLASMA_desc A, int ii, int jj, int i, int j,
         *tau  = (*beta - x0) / creal(*beta);
         /* todo: use zladiv or dladiv */
         scale = 1. / (x0 - *beta);
-        
+
         /* x *= scale */
         i2 = i;
         for( kk = ii; kk < A.mt; ++kk ) {
@@ -137,49 +137,3 @@ void CORE_zgeqp3_larfg( PLASMA_desc A, int ii, int jj, int i, int j,
     Aij = A(ii,jj);
     Aij[i + j*lda] = 1.;
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zgeqp3_larfg(Quark *quark, Quark_Task_Flags *task_flags,
-                             PLASMA_desc A, int ii, int jj, int i, int j,
-                             PLASMA_Complex64_t *tau, PLASMA_Complex64_t *beta )
-{
-    Quark_Task *task;
-    int kk;
-    
-    DAG_SET_PROPERTIES("larfg", "red");
-    task = QUARK_Task_Init( quark, CORE_zgeqp3_larfg_quark, task_flags );
-    
-    QUARK_Task_Pack_Arg( quark, task, sizeof(PLASMA_desc),        &A,    VALUE          );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(int),                &ii,   VALUE          );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(int),                &jj,   VALUE          );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(int),                &i,    VALUE          );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(int),                &j,    VALUE          );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(PLASMA_Complex64_t), tau,           OUTPUT );
-    QUARK_Task_Pack_Arg( quark, task, sizeof(PLASMA_Complex64_t), beta,          OUTPUT );
-    
-    /* depends on block column */
-    for( kk = ii; kk < A.mt; ++kk ) {
-        QUARK_Task_Pack_Arg( quark, task, sizeof(PLASMA_Complex64_t)*A.nb*A.nb, A(kk,jj), INOUT );
-    }
-    
-    QUARK_Insert_Task_Packed( quark, task );
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zgeqp3_larfg_quark = PCORE_zgeqp3_larfg_quark
-#define CORE_zgeqp3_larfg_quark PCORE_zgeqp3_larfg_quark
-#endif
-void CORE_zgeqp3_larfg_quark(Quark *quark)
-{
-    PLASMA_desc A;
-    int ii, jj, i, j;
-    PLASMA_Complex64_t *tau, *beta;
-    
-    quark_unpack_args_7( quark, A, ii, jj, i, j, tau, beta );
-    CORE_zgeqp3_larfg(          A, ii, jj, i, j, tau, beta );
-}
