@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @author Mathieu Faverge
  * @author Jakub Kurzak
@@ -138,56 +138,3 @@ int CORE_zgetrf_incpiv(int M, int N, int IB,
     }
     return PLASMA_SUCCESS;
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zgetrf_incpiv(Quark *quark, Quark_Task_Flags *task_flags,
-                              int m, int n, int ib, int nb,
-                              PLASMA_Complex64_t *A, int lda,
-                              int *IPIV,
-                              PLASMA_sequence *sequence, PLASMA_request *request,
-                              PLASMA_bool check_info, int iinfo)
-{
-    DAG_CORE_GETRF;
-    QUARK_Insert_Task(quark, CORE_zgetrf_incpiv_quark, task_flags,
-        sizeof(int),                        &m,             VALUE,
-        sizeof(int),                        &n,             VALUE,
-        sizeof(int),                        &ib,            VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A,                     INOUT,
-        sizeof(int),                        &lda,           VALUE,
-        sizeof(int)*nb,                      IPIV,                  OUTPUT,
-        sizeof(PLASMA_sequence*),           &sequence,      VALUE,
-        sizeof(PLASMA_request*),            &request,       VALUE,
-        sizeof(PLASMA_bool),                &check_info,    VALUE,
-        sizeof(int),                        &iinfo,         VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zgetrf_incpiv_quark = PCORE_zgetrf_incpiv_quark
-#define CORE_zgetrf_incpiv_quark PCORE_zgetrf_incpiv_quark
-#endif
-void CORE_zgetrf_incpiv_quark(Quark *quark)
-{
-    int m;
-    int n;
-    int ib;
-    PLASMA_Complex64_t *A;
-    int lda;
-    int *IPIV;
-    PLASMA_sequence *sequence;
-    PLASMA_request *request;
-    PLASMA_bool check_info;
-    int iinfo;
-
-    int info;
-
-    quark_unpack_args_10(quark, m, n, ib, A, lda, IPIV, sequence, request, check_info, iinfo);
-    CORE_zgetrf_incpiv(m, n, ib, A, lda, IPIV, &info);
-    if (info != PLASMA_SUCCESS && check_info)
-        plasma_sequence_flush(quark, sequence, request, iinfo+info);
-}
