@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Omar Zenati
  * @author Mathieu Faverge
  * @date 2013-02-01
@@ -40,8 +40,8 @@
  *  @param[in] N
  *          The number of columns of the matrix A.  N >= 0.
  *
- *  @param[in] NB
- *          The block size to switch between blocked and unblocked code
+ *  @param[in] IB
+ *          The block size to switch between blocked and unblocked code.
  *
  *  @param[in,out] A
  *          On entry, the M-by-N matrix to be factored.
@@ -133,51 +133,3 @@ int CORE_zgetrf_nopiv(int M, int N, int IB,
     }
     return info;
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zgetrf_nopiv(Quark *quark, Quark_Task_Flags *task_flags,
-                             int m, int n, int ib, int nb,
-                             PLASMA_Complex64_t *A, int lda,
-                             PLASMA_sequence *sequence, PLASMA_request *request,
-                             int iinfo)
-{
-    DAG_CORE_GETRF;
-    QUARK_Insert_Task(quark, CORE_zgetrf_nopiv_quark, task_flags,
-        sizeof(int),                        &m,             VALUE,
-        sizeof(int),                        &n,             VALUE,
-        sizeof(int),                        &ib,            VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A,                     INOUT | LOCALITY,
-        sizeof(int),                        &lda,           VALUE,
-        sizeof(PLASMA_sequence*),           &sequence,      VALUE,
-        sizeof(PLASMA_request*),            &request,       VALUE,
-        sizeof(int),                        &iinfo,         VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zgetrf_nopiv_quark = PCORE_zgetrf_nopiv_quark
-#define CORE_zgetrf_nopiv_quark PCORE_zgetrf_nopiv_quark
-#endif
-void CORE_zgetrf_nopiv_quark(Quark *quark)
-{
-    int m;
-    int n;
-    int ib;
-    PLASMA_Complex64_t *A;
-    int lda;
-    PLASMA_sequence *sequence;
-    PLASMA_request *request;
-    int iinfo;
-    int info = 0;
-
-    quark_unpack_args_8(quark, m, n, ib, A, lda, sequence, request, iinfo );
-    info = CORE_zgetrf_nopiv(m, n, ib, A, lda );
-    if (info != PLASMA_SUCCESS) {
-        plasma_sequence_flush(quark, sequence, request, iinfo+info);
-    }
-}
