@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @author Mathieu Faverge
  * @author Piotr Luszczek
@@ -152,65 +152,6 @@ int CORE_zgetrf_reclap(int M, int N,
     return info[0];
 }
 
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zgetrf_reclap(Quark *quark, Quark_Task_Flags *task_flags,
-                              int m, int n, int nb,
-                              PLASMA_Complex64_t *A, int lda,
-                              int *IPIV,
-                              PLASMA_sequence *sequence, PLASMA_request *request,
-                              PLASMA_bool check_info, int iinfo,
-                              int nbthread)
-{
-    DAG_CORE_GETRF;
-    QUARK_Insert_Task(quark, CORE_zgetrf_reclap_quark, task_flags,
-        sizeof(int),                        &m,             VALUE,
-        sizeof(int),                        &n,             VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A,                     INOUT,
-        sizeof(int),                        &lda,           VALUE,
-        sizeof(int)*nb,                      IPIV,                  OUTPUT,
-        sizeof(PLASMA_sequence*),           &sequence,      VALUE,
-        sizeof(PLASMA_request*),            &request,       VALUE,
-        sizeof(PLASMA_bool),                &check_info,    VALUE,
-        sizeof(int),                        &iinfo,         VALUE,
-        sizeof(int),                        &nbthread,      VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zgetrf_reclap_quark = PCORE_zgetrf_reclap_quark
-#define CORE_zgetrf_reclap_quark PCORE_zgetrf_reclap_quark
-#endif
-void CORE_zgetrf_reclap_quark(Quark* quark)
-{
-    int M;
-    int N;
-    PLASMA_Complex64_t *A;
-    int LDA;
-    int *IPIV;
-    PLASMA_sequence *sequence;
-    PLASMA_request *request;
-    PLASMA_bool check_info;
-    int iinfo;
-
-    int info[3];
-    int maxthreads;
-
-    quark_unpack_args_10(quark, M, N, A, LDA, IPIV, sequence, request,
-                         check_info, iinfo, maxthreads );
-
-    info[1] = QUARK_Get_RankInTask(quark);
-    info[2] = maxthreads;
-
-    CORE_zgetrf_reclap( M, N, A, LDA, IPIV, info );
-    if (info[1] == 0 && info[0] != PLASMA_SUCCESS && check_info)
-        plasma_sequence_flush(quark, sequence, request, iinfo + info[0] );
-}
-
 /*******************************************************************
  *   Additional routines
  */
