@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @date 2010-11-15
  * @precisions normal z -> c d s
@@ -161,7 +161,7 @@ int CORE_zherfb( PLASMA_enum uplo, int n,
                 *(WORK + j + i * ldwork) = conj( tmp );
             }
         }
-            
+
         /* Left */
         CORE_zunmqr(PlasmaLeft, PlasmaConjTrans, n, n, k, ib,
                     A, lda, T, ldt, WORK, ldwork, WORK+nb*ldwork, ldwork);
@@ -199,62 +199,3 @@ int CORE_zherfb( PLASMA_enum uplo, int n,
     }
     return 0;
 }
-
-
-/***************************************************************************//**
- * This kernel is just a workaround for now... will be deleted eventually
- * and replaced by the one above (Piotr's Task)
- **/
-void QUARK_CORE_zherfb(Quark *quark, Quark_Task_Flags *task_flags,
-                       PLASMA_enum uplo,
-                       int n, int k, int ib, int nb,
-                       const PLASMA_Complex64_t *A, int lda,
-                       const PLASMA_Complex64_t *T, int ldt,
-                       PLASMA_Complex64_t *C, int ldc)
-{
-    /* TODO: Understand why A needs to be INOUT and not INPUT */
-    DAG_CORE_HERFB;
-    QUARK_Insert_Task(
-        quark, CORE_zherfb_quark, task_flags,
-        sizeof(PLASMA_enum),                     &uplo,  VALUE,
-        sizeof(int),                             &n,     VALUE,
-        sizeof(int),                             &k,     VALUE,
-        sizeof(int),                             &ib,    VALUE,
-        sizeof(int),                             &nb,    VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,        A,          uplo == PlasmaUpper ? INOUT|QUARK_REGION_U : INOUT|QUARK_REGION_L,
-        sizeof(int),                             &lda,   VALUE,
-        sizeof(PLASMA_Complex64_t)*ib*nb,        T,          INPUT,
-        sizeof(int),                             &ldt,   VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,        C,          uplo == PlasmaUpper ? INOUT|QUARK_REGION_D|QUARK_REGION_U : INOUT|QUARK_REGION_D|QUARK_REGION_L,
-        sizeof(int),                             &ldc,   VALUE,
-        sizeof(PLASMA_Complex64_t)*2*nb*nb,    NULL,         SCRATCH,
-        sizeof(int),                             &nb,    VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zherfb_quark = PCORE_zherfb_quark
-#define CORE_zherfb_quark PCORE_zherfb_quark
-#endif
-void CORE_zherfb_quark(Quark *quark)
-{
-    PLASMA_enum uplo;
-    int n;
-    int k;
-    int ib;
-    int nb;
-    PLASMA_Complex64_t *A;
-    int lda;
-    PLASMA_Complex64_t *T;
-    int ldt;
-    PLASMA_Complex64_t *C;
-    int ldc;
-    PLASMA_Complex64_t *WORK;
-    int ldwork;
-
-    quark_unpack_args_13(quark, uplo, n, k, ib, nb, A, lda, T, ldt, C, ldc, WORK, ldwork);
-    CORE_zherfb(uplo, n, k, ib, nb, A, lda, T, ldt, C, ldc, WORK, ldwork);
-}
