@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @date 2010-11-15
  * @precisions normal z -> c d s
@@ -15,8 +15,7 @@
 #include <lapacke.h>
 #include "common.h"
 
-/***************************************************************************/
-/**
+/***************************************************************************//**
  *
  * @ingroup CORE_PLASMA_Complex64_t
  *
@@ -75,41 +74,3 @@ void CORE_zlaset2(PLASMA_enum uplo, int M, int N,
             M, N, alpha, alpha, A, LDA);
     }
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zlaset2(Quark *quark, Quark_Task_Flags *task_flags,
-                       PLASMA_enum uplo, int M, int N,
-                       PLASMA_Complex64_t alpha, PLASMA_Complex64_t *A, int LDA)
-{
-    DAG_CORE_LASET;
-    QUARK_Insert_Task(quark, CORE_zlaset2_quark, task_flags,
-        sizeof(PLASMA_enum),                &uplo,  VALUE,
-        sizeof(int),                        &M,     VALUE,
-        sizeof(int),                        &N,     VALUE,
-        sizeof(PLASMA_Complex64_t),         &alpha, VALUE,
-        sizeof(PLASMA_Complex64_t)*M*N,     A,      OUTPUT,
-        sizeof(int),                        &LDA,   VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zlaset2_quark = PCORE_zlaset2_quark
-#define CORE_zlaset2_quark PCORE_zlaset2_quark
-#endif
-void CORE_zlaset2_quark(Quark *quark)
-{
-    PLASMA_enum uplo;
-    int M;
-    int N;
-    PLASMA_Complex64_t alpha;
-    PLASMA_Complex64_t *A;
-    int LDA;
-
-    quark_unpack_args_6(quark, uplo, M, N, alpha, A, LDA);
-    CORE_zlaset2(uplo, M, N, alpha, A, LDA);
-}
