@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Piotr Luszczek
  * @author Pierre Lemarinier
  * @author Mathieu Faverge
@@ -15,60 +15,68 @@
  *
  **/
 #include "common.h"
+#include "random.h"
 
 #define COMPLEX
 #undef REAL
 
-/*
- Rnd64seed is a global variable but it doesn't spoil thread safety. All matrix
- generating threads only read Rnd64seed. It is safe to set Rnd64seed before
- and after any calls to create_tile(). The only problem can be caused if
- Rnd64seed is changed during the matrix generation time.
- */
-
-//static unsigned long long int Rnd64seed = 100;
-#define Rnd64_A 6364136223846793005ULL
-#define Rnd64_C 1ULL
-#define RndF_Mul 5.4210108624275222e-20f
-#define RndD_Mul 5.4210108624275222e-20
-
 #ifdef COMPLEX
 #define NBELEM   2
 #else
 #define NBELEM   1
 #endif
 
-static unsigned long long int
-Rnd64_jump(unsigned long long int n, unsigned long long int seed ) {
-  unsigned long long int a_k, c_k, ran;
-  int i;
-
-  a_k = Rnd64_A;
-  c_k = Rnd64_C;
-
-  ran = seed;
-  for (i = 0; n; n >>= 1, i++) {
-    if (n & 1)
-      ran = a_k * ran + c_k;
-    c_k *= (a_k + 1);
-    a_k *= a_k;
-  }
-
-  return ran;
-}
-
+/***************************************************************************//**
+ *
+ * @ingroup CORE_PLASMA_Complex64_t
+ *
+ *  CORE_zplgsy generates a symmetric matrix.
+ *
+ *******************************************************************************
+ *
+ * @param[in] bump
+ *         Scalar added to the diagonal of the full Matrix A to make it diagonal
+ *         dominant.
+ *
+ * @param[in] m
+ *         The number of rows of the tile A. m >= 0.
+ *
+ * @param[in] n
+ *         The number of columns of the tile A. n >= 0.
+ *
+ * @param[in,out] A
+ *         On entry, the m-by-n tile to be initialized.
+ *         On exit, the tile initialized in the mtxtype format.
+ *
+ * @param[in] lda
+ *         The leading dimension of the tile A. lda >= max(1,m).
+ *
+ * @param[in] gM
+ *         The global number of rows of the full matrix, A is belonging to. gM >= (m0+M).
+ *
+ * @param[in] m0
+ *         The index of the first row of tile A in the full matrix. m0 >= 0.
+ *
+ * @param[in] n0
+ *         The index of the first column of tile A in the full matrix. n0 >= 0.
+ *
+ * @param[in] seed
+ *         The seed used for random generation. Must be the same for
+ *         all tiles initialized with this routine.
+ *
+ ******************************************************************************/
 #if defined(PLASMA_HAVE_WEAK)
 #pragma weak CORE_zplgsy = PCORE_zplgsy
 #define CORE_zplgsy PCORE_zplgsy
 #endif
 void CORE_zplgsy( PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A, int lda,
-                  int bigM, int m0, int n0, unsigned long long int seed )
+                  int gM, int m0, int n0, unsigned long long int seed )
 {
     PLASMA_Complex64_t *tmp = A;
     int64_t i, j;
     unsigned long long int ran, jump;
 
-    jump = (unsigned long long int)m0 + (unsigned long long int)n0 * (unsigned long long int)bigM;
+    jump = (unsigned long long int)m0 + (unsigned long long int)n0 * (unsigned long long int)gM;
 
     /*
      * Tile diagonal
@@ -87,7 +95,7 @@ void CORE_zplgsy( PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A,
                 tmp++;
             }
             tmp  += (lda - i + j + 1);
-            jump += bigM + 1;
+            jump += gM + 1;
         }
 
         for (j = 0; j < n; j++) {
@@ -115,7 +123,7 @@ void CORE_zplgsy( PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A,
                 tmp++;
             }
             tmp  += (lda - i);
-            jump += bigM;
+            jump += gM;
         }
     }
     /*
@@ -123,7 +131,7 @@ void CORE_zplgsy( PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A,
      */
     else if ( m0 < n0 ) {
         /* Overwrite jump */
-        jump = n0 + m0 * bigM;
+        jump = n0 + m0 * gM;
 
         for (i = 0; i < m; i++) {
             ran = Rnd64_jump( NBELEM * jump, seed );
@@ -136,52 +144,7 @@ void CORE_zplgsy( PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A,
                 ran = Rnd64_A * ran + Rnd64_C;
 #endif
             }
-            jump += bigM;
+            jump += gM;
         }
     }
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_zplgsy( Quark *quark, Quark_Task_Flags *task_flags,
-                        PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A, int lda,
-                        int bigM, int m0, int n0, unsigned long long int seed )
-{
-    DAG_CORE_PLGSY;
-    QUARK_Insert_Task(quark, CORE_zplgsy_quark, task_flags,
-        sizeof(PLASMA_Complex64_t),       &bump, VALUE,
-        sizeof(int),                      &m,    VALUE,
-        sizeof(int),                      &n,    VALUE,
-        sizeof(PLASMA_Complex64_t)*lda*n, A,         OUTPUT,
-        sizeof(int),                      &lda,  VALUE,
-        sizeof(int),                      &bigM, VALUE,
-        sizeof(int),                      &m0,   VALUE,
-        sizeof(int),                      &n0,   VALUE,
-        sizeof(unsigned long long int),   &seed, VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_zplgsy_quark = PCORE_zplgsy_quark
-#define CORE_zplgsy_quark PCORE_zplgsy_quark
-#endif
-void CORE_zplgsy_quark(Quark *quark)
-{
-    PLASMA_Complex64_t bump;
-    int m;
-    int n;
-    PLASMA_Complex64_t *A;
-    int lda;
-    int bigM;
-    int m0;
-    int n0;
-    unsigned long long int seed;
-
-    quark_unpack_args_9( quark, bump, m, n, A, lda, bigM, m0, n0, seed );
-    CORE_zplgsy( bump, m, n, A, lda, bigM, m0, n0, seed );
-}
-
