@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @author Mathieu Faverge
  * @author Jakub Kurzak
@@ -211,54 +211,3 @@ int CORE_ztslqt(int M, int N, int IB,
     }
     return PLASMA_SUCCESS;
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_ztslqt(Quark *quark, Quark_Task_Flags *task_flags,
-                       int m, int n, int ib, int nb,
-                       PLASMA_Complex64_t *A1, int lda1,
-                       PLASMA_Complex64_t *A2, int lda2,
-                       PLASMA_Complex64_t *T, int ldt)
-{
-    DAG_CORE_TSLQT;
-    /* TODO: Regions are commented for 2-sided factorizations that have a dependency problem with it */
-    QUARK_Insert_Task(quark, CORE_ztslqt_quark, task_flags,
-        sizeof(int),                        &m,     VALUE,
-        sizeof(int),                        &n,     VALUE,
-        sizeof(int),                        &ib,    VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A1,            INOUT | QUARK_REGION_D | QUARK_REGION_L ,
-        sizeof(int),                        &lda1,  VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A2,            INOUT | LOCALITY,
-        sizeof(int),                        &lda2,  VALUE,
-        sizeof(PLASMA_Complex64_t)*ib*nb,    T,             OUTPUT,
-        sizeof(int),                        &ldt,   VALUE,
-        sizeof(PLASMA_Complex64_t)*nb,       NULL,          SCRATCH,
-        sizeof(PLASMA_Complex64_t)*ib*nb,    NULL,          SCRATCH,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_ztslqt_quark = PCORE_ztslqt_quark
-#define CORE_ztslqt_quark PCORE_ztslqt_quark
-#endif
-void CORE_ztslqt_quark(Quark *quark)
-{
-    int m;
-    int n;
-    int ib;
-    PLASMA_Complex64_t *A1;
-    int lda1;
-    PLASMA_Complex64_t *A2;
-    int lda2;
-    PLASMA_Complex64_t *T;
-    int ldt;
-    PLASMA_Complex64_t *TAU;
-    PLASMA_Complex64_t *WORK;
-
-    quark_unpack_args_11(quark, m, n, ib, A1, lda1, A2, lda2, T, ldt, TAU, WORK);
-    CORE_ztslqt(m, n, ib, A1, lda1, A2, lda2, T, ldt, TAU, WORK);
-}
