@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Hatem Ltaief
  * @author Mathieu Faverge
  * @author Jakub Kurzak
@@ -166,71 +166,3 @@ int CORE_ztsmqr_hetra1( PLASMA_enum side, PLASMA_enum trans,
 
     return PLASMA_SUCCESS;
 }
-
-/***************************************************************************//**
- *
- **/
-void QUARK_CORE_ztsmqr_hetra1(Quark *quark, Quark_Task_Flags *task_flags,
-                              PLASMA_enum side, PLASMA_enum trans,
-                              int m1, int n1, int m2, int n2, int k, int ib, int nb,
-                              PLASMA_Complex64_t *A1, int lda1,
-                              PLASMA_Complex64_t *A2, int lda2,
-                              const PLASMA_Complex64_t *V, int ldv,
-                              const PLASMA_Complex64_t *T, int ldt)
-{
-    int ldwork = side == PlasmaLeft ? ib : nb;
-
-    DAG_CORE_TSMQR;
-    QUARK_Insert_Task(quark, CORE_ztsmqr_hetra1_quark, task_flags,
-        sizeof(PLASMA_enum),                &side,  VALUE,
-        sizeof(PLASMA_enum),                &trans, VALUE,
-        sizeof(int),                        &m1,    VALUE,
-        sizeof(int),                        &n1,    VALUE,
-        sizeof(int),                        &m2,    VALUE,
-        sizeof(int),                        &n2,    VALUE,
-        sizeof(int),                        &k,     VALUE,
-        sizeof(int),                        &ib,    VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A1,            INOUT|QUARK_REGION_L|QUARK_REGION_D,
-        sizeof(int),                        &lda1,  VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    A2,            INOUT,
-        sizeof(int),                        &lda2,  VALUE,
-        sizeof(PLASMA_Complex64_t)*nb*nb,    V,             INPUT,
-        sizeof(int),                        &ldv,   VALUE,
-        sizeof(PLASMA_Complex64_t)*ib*nb,    T,             INPUT,
-        sizeof(int),                        &ldt,   VALUE,
-        sizeof(PLASMA_Complex64_t)*ib*nb,    NULL,          SCRATCH,
-        sizeof(int),                        &ldwork, VALUE,
-        0);
-}
-
-/***************************************************************************//**
- *
- **/
-#if defined(PLASMA_HAVE_WEAK)
-#pragma weak CORE_ztsmqr_hetra1_quark = PCORE_ztsmqr_hetra1_quark
-#define CORE_ztsmqr_hetra1_quark PCORE_ztsmqr_hetra1_quark
-#endif
-void CORE_ztsmqr_hetra1_quark(Quark *quark)
-{
-    PLASMA_enum side;
-    PLASMA_enum trans;
-    int m1;
-    int n1;
-    int m2;
-    int n2;
-    int k;
-    int ib;
-    PLASMA_Complex64_t *A1;
-    int lda1;
-    PLASMA_Complex64_t *A2;
-    int lda2;
-    PLASMA_Complex64_t *V;
-    int ldv;
-    PLASMA_Complex64_t *T;
-    int ldt;
-    PLASMA_Complex64_t *WORK;
-    int ldwork;
-
-    quark_unpack_args_18(quark, side, trans, m1, n1, m2, n2, k, ib, A1, lda1, A2, lda2, V, ldv, T, ldt, WORK, ldwork);
-    CORE_ztsmqr_hetra1(side, trans, m1, n1, m2, n2, k, ib, A1, lda1, A2, lda2, V, ldv, T, ldt, WORK, ldwork);
-}
