@@ -1,5 +1,9 @@
 var modules =
 [
+    [ "Kernel Interface - Single Real", "group__CORE__float.html", "group__CORE__float" ],
+    [ "Kerne Interface - Double Real", "group__CORE__double.html", "group__CORE__double" ],
+    [ "Kerne Interface - Single Complex", "group__CORE__PLASMA__Complex32__t.html", "group__CORE__PLASMA__Complex32__t" ],
+    [ "Kerne Interface - Double Complex", "group__CORE__PLASMA__Complex64__t.html", "group__CORE__PLASMA__Complex64__t" ],
     [ "Simple Interface - Single Real", "group__float.html", "group__float" ],
     [ "Simple Interface - Double Real", "group__double.html", "group__double" ],
     [ "Simple Interface - Single Complex", "group__PLASMA__Complex32__t.html", "group__PLASMA__Complex32__t" ],
