@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Jakub Kurzak
  * @author Hatem Ltaief
  * @author Mathieu Faverge
@@ -63,19 +63,10 @@ void CORE_zgemm(PLASMA_enum transA, PLASMA_enum transB,
                 PLASMA_Complex64_t alpha, const PLASMA_Complex64_t *A, int LDA,
                                           const PLASMA_Complex64_t *B, int LDB,
                 PLASMA_Complex64_t beta,        PLASMA_Complex64_t *C, int LDC);
-void CORE_zgemm_tile(PLASMA_enum transA, PLASMA_enum transB,
-                     int M, int N, int K,
-                     const PLASMA_Complex64_t *alpha, const PLASMA_Complex64_t *A, int LDA,
-                                                      const PLASMA_Complex64_t *B, int LDB,
-                     const PLASMA_Complex64_t *beta,        PLASMA_Complex64_t *C, int LDC);
 void CORE_zgemv(PLASMA_enum trans, int M, int N,
                 PLASMA_Complex64_t alpha, const PLASMA_Complex64_t *A, int LDA,
                                           const PLASMA_Complex64_t *x, int incx,
                 PLASMA_Complex64_t beta,        PLASMA_Complex64_t *y, int incy);
-void CORE_zgemv_tile(PLASMA_enum trans, int M, int N,
-                     const PLASMA_Complex64_t *alpha, const PLASMA_Complex64_t *A, int LDA,
-                                                      const PLASMA_Complex64_t *x, int incx,
-                     const PLASMA_Complex64_t *beta,        PLASMA_Complex64_t *y, int incy);
 void CORE_zgeqp3_init( int n, int *jpvt );
 void CORE_zgeqp3_larfg( PLASMA_desc A, int ii, int jj, int i, int j,
                         PLASMA_Complex64_t *tau, PLASMA_Complex64_t *beta );
@@ -117,7 +108,9 @@ int  CORE_zgetrf_nopiv(int m, int n, int ib,
 int  CORE_zgetrf_reclap(int M, int N,
                         PLASMA_Complex64_t *A, int LDA,
                         int *IPIV, int *info);
+void CORE_zgetrf_reclap_init(void);
 int  CORE_zgetrf_rectil(const PLASMA_desc A, int *IPIV, int *info);
+void CORE_zgetrf_rectil_init(void);
 void CORE_zgetrip(int m, int n, PLASMA_Complex64_t *A,
                   PLASMA_Complex64_t *work);
 int CORE_zhbelr(PLASMA_enum uplo, int N,
@@ -209,6 +202,10 @@ void CORE_zlanhe(int norm, PLASMA_enum uplo, int N,
 void CORE_zlansy(int norm, PLASMA_enum uplo, int N,
                  const PLASMA_Complex64_t *A, int LDA,
                  double *work, double *normA);
+void CORE_zlantr(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag,
+                 int M, int N,
+                 const PLASMA_Complex64_t *A, int LDA,
+                 double *work, double *normA);
 int CORE_zlarfb_gemm(PLASMA_enum side, PLASMA_enum trans, PLASMA_enum direct, PLASMA_enum storev,
                      int M, int N, int K,
                      const PLASMA_Complex64_t *V, int LDV,
@@ -278,6 +275,28 @@ void CORE_zplgsy(PLASMA_Complex64_t bump, int m, int n, PLASMA_Complex64_t *A, i
                  int bigM, int m0, int n0, unsigned long long int seed );
 void CORE_zplrnt(int m, int n, PLASMA_Complex64_t *A, int lda,
                  int bigM, int m0, int n0, unsigned long long int seed );
+int  CORE_zpltmg(PLASMA_enum mtxtype, int m, int n, PLASMA_Complex64_t *A, int lda,
+                  int gM, int gN, int m0, int n0, unsigned long long int seed );
+int  CORE_zpltmg_chebvand( int M, int N, PLASMA_Complex64_t *A, int LDA,
+                           int gN, int m0, int n0,
+                           PLASMA_Complex64_t *W );
+int  CORE_zpltmg_circul( int M, int N, PLASMA_Complex64_t *A, int LDA,
+                         int gM, int m0, int n0,
+                         const PLASMA_Complex64_t *V );
+void CORE_zpltmg_condexq( int M, int N, PLASMA_Complex64_t *Q, int LDQ );
+void CORE_zpltmg_fiedler(int m, int n,
+                         const PLASMA_Complex64_t *X, int incX,
+                         const PLASMA_Complex64_t *Y, int incY,
+                         PLASMA_Complex64_t *A, int lda);
+int  CORE_zpltmg_hankel( PLASMA_enum uplo, int M, int N, PLASMA_Complex64_t *A, int LDA,
+                         int m0, int n0, int nb,
+                         const PLASMA_Complex64_t *V1,
+                         const PLASMA_Complex64_t *V2 );
+void CORE_zpltmg_toeppd1( int gM, int m0, int M, PLASMA_Complex64_t *W,
+                          unsigned long long int seed );
+void CORE_zpltmg_toeppd2( int M, int N, int K, int m0, int n0,
+                          const PLASMA_Complex64_t *W,
+                          PLASMA_Complex64_t *A, int LDA );
 void CORE_zpotrf(PLASMA_enum uplo, int N, PLASMA_Complex64_t *A, int LDA, int *INFO);
 void CORE_zsetvar(const PLASMA_Complex64_t *alpha, PLASMA_Complex64_t *x);
 void CORE_zshift(int s, int m, int n, int L,
@@ -311,6 +330,8 @@ void CORE_zswpab(int i, int n1, int n2,
                  PLASMA_Complex64_t *A, PLASMA_Complex64_t *work);
 int  CORE_zswptr_ontile(PLASMA_desc descA, int i1, int i2, const int *ipiv, int inc,
                         const PLASMA_Complex64_t *Akk, int ldak);
+void CORE_ztrasm(PLASMA_enum storev, PLASMA_enum uplo, PLASMA_enum diag,
+                 int M, int N, const PLASMA_Complex64_t *A, int lda, double *work);
 void CORE_ztrdalg1(int n,
                         int nb,
                         PLASMA_Complex64_t *A,
@@ -330,6 +351,9 @@ void CORE_ztrsm(PLASMA_enum side, PLASMA_enum uplo,
                 int M, int N,
                 PLASMA_Complex64_t alpha, const PLASMA_Complex64_t *A, int LDA,
                                                 PLASMA_Complex64_t *B, int LDB);
+int  CORE_ztrssq(PLASMA_enum uplo, PLASMA_enum diag, int M, int N,
+                 const PLASMA_Complex64_t *A, int LDA,
+                 double *scale, double *sumsq);
 void CORE_ztrtri(PLASMA_enum uplo, PLASMA_enum diag, int N,
                  PLASMA_Complex64_t *A, int LDA, int *info);
 int  CORE_ztslqt(int M, int N, int IB,
@@ -433,6 +457,7 @@ int  CORE_zunmqr(PLASMA_enum side, PLASMA_enum trans,
                  PLASMA_Complex64_t *C, int LDC,
                  PLASMA_Complex64_t *WORK, int LDWORK);
 
+#if defined(QUARK_H)
 /** ****************************************************************************
  *  Declarations of QUARK wrappers (called by PLASMA) - alphabetical order
  **/
@@ -681,6 +706,15 @@ void QUARK_CORE_zlansy_f1(Quark *quark, Quark_Task_Flags *task_flags,
                           const PLASMA_Complex64_t *A, int LDA, int szeA,
                           int szeW, double *result,
                           double *fake, int szeF);
+void QUARK_CORE_zlantr(Quark *quark, Quark_Task_Flags *task_flags,
+                       PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, int M, int N,
+                       const PLASMA_Complex64_t *A, int LDA, int szeA,
+                       int szeW, double *result);
+void QUARK_CORE_zlantr_f1(Quark *quark, Quark_Task_Flags *task_flags,
+                          PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, int M, int N,
+                          const PLASMA_Complex64_t *A, int LDA, int szeA,
+                          int szeW, double *result,
+                          double *fake, int szeF);
 void QUARK_CORE_zlaset(Quark *quark, Quark_Task_Flags *task_flags,
                        PLASMA_enum uplo, int n1, int n2, PLASMA_Complex64_t alpha,
                        PLASMA_Complex64_t beta, PLASMA_Complex64_t *tileA, int ldtilea);
@@ -727,6 +761,35 @@ void QUARK_CORE_zplgsy(Quark *quark, Quark_Task_Flags *task_flags,
 void QUARK_CORE_zplrnt(Quark *quark, Quark_Task_Flags *task_flags,
                        int m, int n, PLASMA_Complex64_t *A, int lda,
                        int bigM, int m0, int n0, unsigned long long int seed );
+void QUARK_CORE_zpltmg(Quark *quark, Quark_Task_Flags *task_flags,
+                        PLASMA_enum mtxtype, int m, int n, PLASMA_Complex64_t *A, int lda,
+                        int gM, int gN, int m0, int n0, unsigned long long int seed );
+void QUARK_CORE_zpltmg_chebvand( Quark *quark, Quark_Task_Flags *task_flags,
+                                 int M, int N, PLASMA_Complex64_t *A, int LDA,
+                                 int gN, int m0, int n0,
+                                 PLASMA_Complex64_t *W );
+void QUARK_CORE_zpltmg_circul( Quark *quark, Quark_Task_Flags *task_flags,
+                               int M, int N, PLASMA_Complex64_t *A, int LDA,
+                               int gM, int m0, int n0,
+                               const PLASMA_Complex64_t *W );
+void QUARK_CORE_zpltmg_fiedler(Quark *quark, Quark_Task_Flags *task_flags,
+                               int m, int n,
+                               const PLASMA_Complex64_t *X, int incX,
+                               const PLASMA_Complex64_t *Y, int incY,
+                               PLASMA_Complex64_t *A, int lda);
+void QUARK_CORE_zpltmg_hankel( Quark *quark, Quark_Task_Flags *task_flags,
+                               PLASMA_enum uplo, int M, int N, PLASMA_Complex64_t *A, int LDA,
+                               int m0, int n0, int nb,
+                               const PLASMA_Complex64_t *V1,
+                               const PLASMA_Complex64_t *V2);
+void QUARK_CORE_zpltmg_toeppd1(Quark *quark, Quark_Task_Flags *task_flags,
+                               int gM, int m0, int M,
+                               PLASMA_Complex64_t *W,
+                               unsigned long long int seed);
+void QUARK_CORE_zpltmg_toeppd2(Quark *quark, Quark_Task_Flags *task_flags,
+                               int M, int N, int K, int m0, int n0,
+                               const PLASMA_Complex64_t *W,
+                               PLASMA_Complex64_t *A, int LDA );
 void QUARK_CORE_zpotrf(Quark *quark, Quark_Task_Flags *task_flags,
                        PLASMA_enum uplo, int n, int nb,
                        PLASMA_Complex64_t *A, int lda,
@@ -776,6 +839,15 @@ void QUARK_CORE_zswptr_ontile(Quark *quark, Quark_Task_Flags *task_flags,
                               PLASMA_desc descA, PLASMA_Complex64_t *Aij,
                               int i1,  int i2, const int *ipiv, int inc,
                               const PLASMA_Complex64_t *Akk, int ldak);
+void QUARK_CORE_ztrasm(Quark *quark, Quark_Task_Flags *task_flags,
+                       PLASMA_enum storev, PLASMA_enum uplo, PLASMA_enum diag, int m, int n,
+                       const PLASMA_Complex64_t *A, int lda, int szeA,
+                       double *work, int szeW);
+void QUARK_CORE_ztrasm_f1(Quark *quark, Quark_Task_Flags *task_flags,
+                          PLASMA_enum storev, PLASMA_enum uplo, PLASMA_enum diag, int m, int n,
+                          const PLASMA_Complex64_t *A, int lda, int szeA,
+                          double *work, int szeW,
+                          double *fake, int szeF);
 void QUARK_CORE_ztrdalg1(Quark *quark, Quark_Task_Flags *task_flags,
                         int n,
                         int nb,
@@ -801,6 +873,11 @@ void QUARK_CORE_ztrsm(Quark *quark, Quark_Task_Flags *task_flags,
                       int m, int n, int nb,
                       PLASMA_Complex64_t alpha, const PLASMA_Complex64_t *A, int lda,
                       PLASMA_Complex64_t *B, int ldb);
+void QUARK_CORE_ztrssq_f1( Quark *quark, Quark_Task_Flags *task_flags,
+                           PLASMA_enum uplo, PLASMA_enum diag,
+                           int m, int n, const PLASMA_Complex64_t *A, int lda,
+                           double *scale, double *sumsq,
+                           double *fake, int szeF, int paramF );
 void QUARK_CORE_ztrtri(Quark *quark, Quark_Task_Flags *task_flags,
                        PLASMA_enum uplo, PLASMA_enum diag, int n, int nb,
                        PLASMA_Complex64_t *A, int lda,
@@ -972,6 +1049,7 @@ void CORE_zpamm_quark(Quark *quark);
 void CORE_zplghe_quark(Quark *quark);
 void CORE_zplgsy_quark(Quark *quark);
 void CORE_zplrnt_quark(Quark *quark);
+void CORE_zpltmg_quark(Quark *quark);
 void CORE_zplssq_quark(Quark *quark);
 void CORE_zpotrf_quark(Quark *quark);
 void CORE_zsetvar_quark(Quark *quark);
@@ -1015,6 +1093,8 @@ void CORE_zgemm_p2_quark(Quark* quark);
 void CORE_zgemm_p2f1_quark(Quark* quark);
 void CORE_zgemm_p3_quark(Quark* quark);
 
+#endif /* defined(QUARK_H) */
+
 #ifdef __cplusplus
 }
 #endif
