@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Jakub Kurzak
  * @author Hatem Ltaief
  * @author Mathieu Faverge
@@ -31,6 +31,7 @@ void CORE_zlag2c(int m, int n,
                  const PLASMA_Complex64_t *A, int lda,
                  PLASMA_Complex32_t *B, int ldb, int *info);
 
+#if defined(QUARK_H)
 /** ****************************************************************************
  *  Declarations of QUARK wrappers (called by PLASMA) - alphabetical order
  **/
@@ -50,6 +51,8 @@ void QUARK_CORE_zlag2c(Quark *quark, Quark_Task_Flags *task_flags,
 void CORE_clag2z_quark(Quark *quark);
 void CORE_zlag2c_quark(Quark *quark);
 
+#endif /* defined(QUARK_H) */
+
 #ifdef __cplusplus
 }
 #endif
