@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Jakub Kurzak
  * @author Hatem Ltaief
  * @author Mathieu Faverge
@@ -67,6 +67,7 @@ double PLASMA_zlange(PLASMA_enum norm, int M, int N, PLASMA_Complex64_t *A, int
 double PLASMA_zlanhe(PLASMA_enum norm, PLASMA_enum uplo, int N, PLASMA_Complex64_t *A, int LDA);
 #endif
 double PLASMA_zlansy(PLASMA_enum norm, PLASMA_enum uplo, int N, PLASMA_Complex64_t *A, int LDA);
+double PLASMA_zlantr(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, int M, int N, PLASMA_Complex64_t *A, int LDA);
 int PLASMA_zlaset(PLASMA_enum uplo, int M, int N, PLASMA_Complex64_t alpha, PLASMA_Complex64_t beta, PLASMA_Complex64_t *A, int LDA);
 int PLASMA_zlaswp( int N, PLASMA_Complex64_t *A, int LDA, int K1, int K2, const int *IPIV, int INCX);
 int PLASMA_zlaswpc(int N, PLASMA_Complex64_t *A, int LDA, int K1, int K2, const int *IPIV, int INCX);
@@ -76,6 +77,7 @@ int PLASMA_zplghe( double bump, int N, PLASMA_Complex64_t *A, int LDA, unsigned
 #endif
 int PLASMA_zplgsy( PLASMA_Complex64_t bump, int N, PLASMA_Complex64_t *A, int LDA, unsigned long long int seed);
 int PLASMA_zplrnt( int M, int N, PLASMA_Complex64_t *A, int LDA, unsigned long long int seed);
+int PLASMA_zpltmg( PLASMA_enum mtxtype, int M, int N, PLASMA_Complex64_t *A, int LDA, unsigned long long int seed);
 int PLASMA_zposv(PLASMA_enum uplo, int N, int NRHS, PLASMA_Complex64_t *A, int LDA, PLASMA_Complex64_t *B, int LDB);
 int PLASMA_zpotrf(PLASMA_enum uplo, int N, PLASMA_Complex64_t *A, int LDA);
 int PLASMA_zpotri(PLASMA_enum uplo, int N, PLASMA_Complex64_t *A, int LDA);
@@ -138,6 +140,7 @@ double PLASMA_zlange_Tile(PLASMA_enum norm, PLASMA_desc *A);
 double PLASMA_zlanhe_Tile(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A);
 #endif
 double PLASMA_zlansy_Tile(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A);
+double PLASMA_zlantr_Tile(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, PLASMA_desc *A);
 int PLASMA_zlaset_Tile(PLASMA_enum uplo, PLASMA_Complex64_t alpha, PLASMA_Complex64_t beta, PLASMA_desc *A);
 int PLASMA_zlaswp_Tile(PLASMA_desc *A, int K1, int K2, const int *IPIV, int INCX);
 int PLASMA_zlaswpc_Tile(PLASMA_desc *A, int K1, int K2, const int *IPIV, int INCX);
@@ -147,6 +150,7 @@ int PLASMA_zplghe_Tile(double bump, PLASMA_desc *A, unsigned long long int seed)
 #endif
 int PLASMA_zplgsy_Tile(PLASMA_Complex64_t bump, PLASMA_desc *A, unsigned long long int seed);
 int PLASMA_zplrnt_Tile(PLASMA_desc *A, unsigned long long int seed);
+int PLASMA_zpltmg_Tile(PLASMA_enum mtxtype, PLASMA_desc *A, unsigned long long int seed);
 int PLASMA_zposv_Tile(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B);
 int PLASMA_zpotrf_Tile(PLASMA_enum uplo, PLASMA_desc *A);
 int PLASMA_zpotri_Tile(PLASMA_enum uplo, PLASMA_desc *A);
@@ -201,11 +205,12 @@ int PLASMA_zhegvd_Tile_Async(PLASMA_enum itype, PLASMA_enum jobz, PLASMA_enum up
 int PLASMA_zhegst_Tile_Async(PLASMA_enum itype, PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zhetrd_Tile_Async(PLASMA_enum jobz, PLASMA_enum uplo, PLASMA_desc *A, double *D, double *E, PLASMA_desc *T, PLASMA_Complex64_t *Q, int LDQ, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zlacpy_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B, PLASMA_sequence *sequence, PLASMA_request *request);
-int PLASMA_zlange_Tile_Async(PLASMA_enum norm, PLASMA_desc *A, double *value, PLASMA_sequence *sequence, PLASMA_request *request);
+int PLASMA_zlange_Tile_Async(PLASMA_enum norm, PLASMA_desc *A, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
 #ifdef COMPLEX
-int PLASMA_zlanhe_Tile_Async(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A, double *value, PLASMA_sequence *sequence, PLASMA_request *request);
+int PLASMA_zlanhe_Tile_Async(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
 #endif
-int PLASMA_zlansy_Tile_Async(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A, double *value, PLASMA_sequence *sequence, PLASMA_request *request);
+int PLASMA_zlansy_Tile_Async(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_desc *A, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
+int PLASMA_zlantr_Tile_Async(PLASMA_enum norm, PLASMA_enum uplo, PLASMA_enum diag, PLASMA_desc *A, double *result, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zlaset_Tile_Async(PLASMA_enum uplo, PLASMA_Complex64_t alpha, PLASMA_Complex64_t beta, PLASMA_desc *A, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zlaswp_Tile_Async(PLASMA_desc *A, int K1, int K2, const int *IPIV, int INCX, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zlaswpc_Tile_Async(PLASMA_desc *A, int K1, int K2, const int *IPIV, int INCX, PLASMA_sequence *sequence, PLASMA_request *request);
@@ -215,6 +220,7 @@ int PLASMA_zplghe_Tile_Async(double bump, PLASMA_desc *A, unsigned long long int
 #endif
 int PLASMA_zplgsy_Tile_Async(PLASMA_Complex64_t bump, PLASMA_desc *A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zplrnt_Tile_Async(PLASMA_desc *A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request);
+int PLASMA_zpltmg_Tile_Async(PLASMA_enum mtxtype, PLASMA_desc *A, unsigned long long int seed, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zposv_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_desc *B, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zpotrf_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_sequence *sequence, PLASMA_request *request);
 int PLASMA_zpotri_Tile_Async(PLASMA_enum uplo, PLASMA_desc *A, PLASMA_sequence *sequence, PLASMA_request *request);
