@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Bilel Hadri
  * @author Hatem Ltaief
  * @date 2010-11-15
@@ -612,37 +612,28 @@ static int check_factorization(int M, int N, PLASMA_Complex64_t *A1, PLASMA_Comp
  * Check the solution
  */
 
-static int check_solution(int M, int N, int NRHS, PLASMA_Complex64_t *A1, int LDA, PLASMA_Complex64_t *B1, PLASMA_Complex64_t *B2, int LDB, double eps)
+static int check_solution(int M, int N, int NRHS, PLASMA_Complex64_t *A, int LDA, PLASMA_Complex64_t *B, PLASMA_Complex64_t *X, int LDB, double eps)
 {
     int info_solution;
     double Rnorm, Anorm, Xnorm, Bnorm;
-    PLASMA_Complex64_t alpha, beta;
+    PLASMA_Complex64_t zone, mzone, zzero;
     double result;
     double *work = (double *)malloc(max(M, N)* sizeof(double));
 
-    alpha = 1.0;
-    beta  = -1.0;
+    zone  =  1.0;
+    mzone = -1.0;
+    zzero =  0.0;
 
-    BLAS_zge_norm( blas_colmajor, blas_inf_norm, M, N,    A1, LDA, &Anorm );
-    BLAS_zge_norm( blas_colmajor, blas_inf_norm, M, NRHS, B2, LDB, &Xnorm );
-    BLAS_zge_norm( blas_colmajor, blas_inf_norm, N, NRHS, B1, LDB, &Bnorm );
+    BLAS_zge_norm( blas_colmajor, blas_inf_norm, M, N,    A, LDA, &Anorm );
+    BLAS_zge_norm( blas_colmajor, blas_inf_norm, M, NRHS, B, LDB, &Bnorm );
+    BLAS_zge_norm( blas_colmajor, blas_inf_norm, N, NRHS, X, LDB, &Xnorm );
 
-    cblas_zgemm(CblasColMajor, CblasNoTrans, CblasNoTrans, M, NRHS, N, CBLAS_SADDR(alpha), A1, LDA, B2, LDB, CBLAS_SADDR(beta), B1, LDB);
+    /* Compute Ax - b */
+    cblas_zgemm(CblasColMajor, CblasNoTrans, CblasNoTrans, M, NRHS, N, CBLAS_SADDR(zone), A, LDA, X, LDB, CBLAS_SADDR(mzone), B, LDB);
 
-    if (M >= N) {
-       PLASMA_Complex64_t *Residual = (PLASMA_Complex64_t *)malloc(M*NRHS*sizeof(PLASMA_Complex64_t));
-       memset((void*)Residual, 0, M*NRHS*sizeof(PLASMA_Complex64_t));
-       cblas_zgemm(CblasColMajor, CblasConjTrans, CblasNoTrans, N, NRHS, M, CBLAS_SADDR(alpha), A1, LDA, B1, LDB, CBLAS_SADDR(beta), Residual, M);
-       BLAS_zge_norm( blas_colmajor, blas_inf_norm, M, NRHS, Residual, M, &Rnorm );
-       free(Residual);
-    }
-    else {
-       PLASMA_Complex64_t *Residual = (PLASMA_Complex64_t *)malloc(N*NRHS*sizeof(PLASMA_Complex64_t));
-       memset((void*)Residual, 0, N*NRHS*sizeof(PLASMA_Complex64_t));
-       cblas_zgemm(CblasColMajor, CblasConjTrans, CblasNoTrans, N, NRHS, M, CBLAS_SADDR(alpha), A1, LDA, B1, LDB, CBLAS_SADDR(beta), Residual, N);
-       BLAS_zge_norm( blas_colmajor, blas_inf_norm, N, NRHS, Residual, N, &Rnorm );
-       free(Residual);
-    }
+    /* Compute A' * (Ax - b) */
+    cblas_zgemm(CblasColMajor, CblasConjTrans, CblasNoTrans, N, NRHS, M, CBLAS_SADDR(zone), A, LDA, B, LDB, CBLAS_SADDR(zzero), X, LDB);
+    BLAS_zge_norm( blas_colmajor, blas_inf_norm, N, NRHS, X, LDB, &Rnorm );
 
     if (getenv("PLASMA_TESTING_VERBOSE"))
        printf( "||A||_oo=%f\n||X||_oo=%f\n||B||_oo=%f\n||A X - B||_oo=%e\n", Anorm, Xnorm, Bnorm, Rnorm );
