@@ -6,7 +6,7 @@
  *  PLASMA is a software package provided by Univ. of Tennessee,
  *  Univ. of California Berkeley and Univ. of Colorado Denver
  *
- * @version 2.5.2
+ * @version 2.6.0
  * @author Emmanuel Agullo
  * @author Mathieu Faverge
  * @date 2010-11-15
@@ -103,6 +103,53 @@ int testing_zlange(int argc, char **argv)
         printf("***************************************************\n");
     }
 
+    /* Don't perform real tests while lapacke is not correct */
+#ifdef COMPLEX
+    /* PLASMA ZLANTR */
+    for(n=0; n<4; n++) {
+        for(u=0; u<2; u++) {
+            int d;
+            for(d=0; d<2; d++) {
+                normplasma = PLASMA_zlantr(norm[n], uplo[u], diag[d], M, N, A, LDA);
+                normlapack = LAPACKE_zlantr_work(LAPACK_COL_MAJOR, lapack_const(norm[n]), lapack_const(uplo[u]),
+                                                 lapack_const(diag[d]), M, N, A, LDA, work);
+
+                printf("Lapack %e, Plasma %e\n", normlapack, normplasma);
+
+                result = fabs(normplasma - normlapack) / (normlapack * eps);
+                switch(norm[n]) {
+                case PlasmaMaxNorm:
+                    /* result should be perfectly equal */
+                    break;
+                case PlasmaInfNorm:
+                    /* Sum order on the line can differ */
+                    result = result / (double)N;
+                    break;
+                case PlasmaOneNorm:
+                    /* Sum order on the column can differ */
+                    result = result / (double)M;
+                    break;
+                case PlasmaFrobeniusNorm:
+                    /* Sum oreder on every element can differ */
+                    result = result / ((double)M * (double)N);
+                    break;
+                }
+
+                printf("***************************************************\n");
+                if ( result < 1. ) {
+                    printf(" ---- TESTING ZLANTR (%s, %s, %s)......... PASSED !\n",
+                           normstr[n], uplostr[u], diagstr[d]);
+                }
+                else {
+                    printf(" - TESTING ZLANTR (%s, %s, %s)... FAILED !\n",
+                           normstr[n], uplostr[u], diagstr[d]);
+                }
+                printf("***************************************************\n");
+            }
+        }
+    }
+#endif
+
     /* PLASMA ZLANSY */
     for(n=0; n<4; n++) {
         for(u=0; u<2; u++) {
