@@ -90,6 +90,7 @@ subs = {
     ('cblas_sasum','cblas_dasum','cblas_scasum','cblas_dzasum'),
     ('CORE_sasum','CORE_dasum','CORE_scasum','CORE_dzasum'),
     ('core_sasum','core_dasum','core_scasum','core_dzasum'),
+    ('qwrapper_sasum','qwrapper_dasum','qwrapper_scasum','qwrapper_dzasum'),
     ('ipt_s','ipt_d','ipt_c','ipt_z'),
     ('coreblas_s','coreblas_d','coreblas_c','coreblas_z'),
     ('sytra1','sytra1','hetra1','hetra1'),
@@ -262,13 +263,20 @@ subs = {
     ('strsmpl','dtrsmpl','ctrsmpl','ztrsmpl'),
     ('STRSMPL','DTRSMPL','CTRSMPL','ZTRSMPL'),
     ('splgsy','dplgsy','cplghe','zplghe'),
+    ('SPLGSY','DPLGSY','CPLGHE','ZPLGHE'),
     ('splgsy','dplgsy','cplgsy','zplgsy'),
+    ('SPLGSY','DPLGSY','CPLGSY','ZPLGSY'),
     ('splrnt','dplrnt','cplrnt','zplrnt'),
+    ('SPLRNT','DPLRNT','CPLRNT','ZPLRNT'),
+    ('spltmg','dpltmg','cpltmg','zpltmg'),
+    ('SPLTMG','DPLTMG','CPLTMG','ZPLTMG'),
     ('\*\*T','\*\*T','\*\*H','\*\*H'),
     ('BLAS_s','BLAS_d','BLAS_s','BLAS_d'),
     ('BLAS_s','BLAS_d','BLAS_c','BLAS_z'),
     ('fabsf','fabs','cabsf','cabs'),
     ('imagf','imag','imagf','imag'),
+    ('cosf','cos','ccosf','ccos'),
+    ('powf','pow','cpowf','cpow'),
     ('cblas_sscal','cblas_dscal','cblas_csscal','cblas_zdscal'),
     ('cblas_is','cblas_id','cblas_ic','cblas_iz'),
     ('cblas_is','cblas_id','cblas_is','cblas_id'),
@@ -280,6 +288,7 @@ subs = {
     ('CORE_s','CORE_d','CORE_c','CORE_z'),
     ('CORE_s','CORE_d','CORE_s','CORE_d'),
     ('core_s','core_d','core_c','core_z'),
+    ('qwrapper_s','qwrapper_d','qwrapper_c','qwrapper_z'),
     ('example_s','example_d','example_c','example_z'),
     ('lapack_s','lapack_d','lapack_c','lapack_z'),
     ('lapack_slamch','lapack_dlamch','lapack_slamch','lapack_dlamch'),
